import { ArgumentOutOfRangeException } from '@mobicoop/ddd-library';
import { Role } from '@modules/ad/core/domain/ad.types';
import { Target } from '@modules/ad/core/domain/candidate.types';
import { Actor } from '@modules/ad/core/domain/value-objects/actor.value-object';
import { CarpoolPathItem } from '@modules/ad/core/domain/value-objects/carpool-path-item.value-object';

describe('Carpool Path Item value object', () => {
  it('should create a path item value object', () => {
    const carpoolPathItemVO = new CarpoolPathItem({
      lat: 48.689445,
      lon: 6.17651,
      actors: [
        new Actor({
          role: Role.DRIVER,
          target: Target.NEUTRAL,
        }),
        new Actor({
          role: Role.PASSENGER,
          target: Target.START,
        }),
      ],
    });
    expect(carpoolPathItemVO.lon).toBe(6.17651);
    expect(carpoolPathItemVO.lat).toBe(48.689445);
    expect(carpoolPathItemVO.actors).toHaveLength(2);
  });
  it('should throw an exception if actors is empty', () => {
    expect(() => {
      new CarpoolPathItem({
        lat: 48.689445,
        lon: 6.17651,
        actors: [],
      });
    }).toThrow(ArgumentOutOfRangeException);
  });
  it('should throw an exception if actors contains more than one driver', () => {
    expect(() => {
      new CarpoolPathItem({
        lat: 48.689445,
        lon: 6.17651,
        actors: [
          new Actor({
            role: Role.DRIVER,
            target: Target.NEUTRAL,
          }),
          new Actor({
            role: Role.DRIVER,
            target: Target.START,
          }),
        ],
      });
    }).toThrow(ArgumentOutOfRangeException);
  });
});
