import { Frequency } from '@modules/ad/core/domain/ad.types';
import { ScheduleItemDto } from '@modules/ad/interface/grpc-controllers/dtos/schedule-item.dto';
import { HasDay } from '@modules/ad/interface/grpc-controllers/dtos/validators/decorators/has-day.decorator';
import { Validator } from 'class-validator';

describe('Has day decorator', () => {
  class MyClass {
    @HasDay('schedule', {
      message: 'At least a day is required for a recurrent ad',
    })
    frequency: Frequency;

    schedule: ScheduleItemDto[];
  }

  it('should return a property decorator has a function', () => {
    const hasDay = HasDay('someProperty');
    expect(typeof hasDay).toBe('function');
  });

  it('should validate a punctual frequency associated with a valid schedule', async () => {
    const myClassInstance = new MyClass();
    myClassInstance.frequency = Frequency.PUNCTUAL;
    myClassInstance.schedule = [
      {
        time: '07:15',
      },
    ];
    const validator = new Validator();
    const validation = await validator.validate(myClassInstance);
    expect(validation.length).toBe(0);
  });

  it('should validate a recurrent frequency associated with a valid schedule', async () => {
    const myClassInstance = new MyClass();
    myClassInstance.frequency = Frequency.RECURRENT;
    myClassInstance.schedule = [
      {
        time: '07:15',
        day: 1,
      },
    ];
    const validator = new Validator();
    const validation = await validator.validate(myClassInstance);
    expect(validation.length).toBe(0);
  });

  it('should not validate a recurrent frequency associated with an invalid schedule', async () => {
    const myClassInstance = new MyClass();
    myClassInstance.frequency = Frequency.RECURRENT;
    myClassInstance.schedule = [
      {
        time: '07:15',
      },
    ];
    const validator = new Validator();
    const validation = await validator.validate(myClassInstance);
    expect(validation.length).toBe(1);
  });
});
